==> sale-3.5.3.jar: filiale/xiangyun/sqls/cardChargeQuery.sql <==
SELECT *
     , LEFT(price
    , len(price) - 1)   f_price    --预收气价
     ,
    case when f_price_type = '应交费' then LEFT(price , len(price) - 1) else LEFT(preprice , (len(price) - 1)) end f_preprice --应收气价
FROM (SELECT sg.id                                                                           id,
             sg.f_preamount,                                                                               --预收气费
             sg.f_pregas,                                                                                  --购气量
            case when sg.f_price_type = '应交费' then sg.f_preamount else sg.f_preamount - sg.f_pregas * isnull(sp.f_add_price, 0)  end    f_realamount, --应收气费
             sg.f_operate_date,
             case when sd.id is null then '否' else '是' end                                 f_refund,
             case when sd.id is null then 0 else sg.f_pregas * isnull(sp.f_add_price, 0) end f_refundfee,
             ui.f_userinfo_code,
             ui.f_user_name,
             sg.f_orgid,
             sg.f_orgname,
             sg.f_depid,
             sg.f_depname,
             sg.f_operatorid,
             sg.f_operator,
    sg.f_price_type,
    case
    when sg.f_price_type = '应交费' then
    isnull(sg.f_stair_price1, 0)
    else
    (case
    when isnull(sg.f_stair_price1, 0) - isnull(sp.f_add_price, 0) < 0 then 0
    else isnull(sg.f_stair_price1, 0) - isnull(sp.f_add_price, 0) end) end f_stair_price1,
    isnull(f_stair_gas1, 0)                                                             f_stair_gas1,
    case
    when sg.f_price_type = '应交费' then
    isnull(f_stair_money1, 0)
    else
    (isnull(f_stair_price1, 0) - isnull(sp.f_add_price, 0)) *
    f_stair_gas1 end                                                        f_stair_money1,
    case
    when sg.f_price_type = '应交费' then
    isnull(f_stair_price2, 0)
    else (case
    when isnull(f_stair_price2, isnull(sp.f_add_price, 0)) -
    isnull(sp.f_add_price, 0) < 0 then 0
    else isnull(f_stair_price2, isnull(sp.f_add_price, 0)) -
    isnull(sp.f_add_price, 0) end)
    end                                                                             f_stair_price2,
    isnull(f_stair_gas2, 0)                                                             f_stair_gas2,
    case
    when sg.f_price_type = '应交费' then
    isnull(f_stair_money2, 0)
    else
    (isnull(f_stair_price2, isnull(sp.f_add_price, 0)) - isnull(sp.f_add_price, 0)) *
    f_stair_gas2 end                                                        f_stair_money2,
    case
    when sg.f_price_type = '应交费' then
    isnull(f_stair_price3, 0)
    else
    (case
    when isnull(f_stair_price3, isnull(sp.f_add_price, 0)) -
    isnull(sp.f_add_price, 0) < 0 then 0
    else isnull(f_stair_price3, isnull(sp.f_add_price, 0)) -
    isnull(sp.f_add_price, 0) end) end                                f_stair_price3,
    isnull(f_stair_gas3, 0)                                                             f_stair_gas3,
    case
    when sg.f_price_type = '应交费' then
    isnull(f_stair_money3, 0)
    else
    (isnull(f_stair_price3, isnull(sp.f_add_price, 0)) - isnull(sp.f_add_price, 0)) *
    f_stair_gas3 end                                                        f_stair_money3,
             gd.f_meter_brand,
             uf.f_meternumber,
             uf.f_user_type,
             uf.f_gasproperties,
             ua.f_address,
             sd.f_operate_date                                                               f_refund_date,
             CAST((SELECT '' + CAST(CONVERT(DECIMAL(18, 3), f_price) AS VARCHAR) + '|'
                   FROM t_chargeprice cp
                   WHERE sg.id = cp.f_charge_id
                     and cp.f_gas > 0
                   FOR xml path ( '' )) AS VARCHAR)                                          price,
             CAST((SELECT '' + CAST(CONVERT(DECIMAL(18, 3), f_price - isnull(sp.f_add_price, 0)) AS VARCHAR) + '|'
                   FROM t_chargeprice cp
                   WHERE sg.id = cp.f_charge_id
                     and cp.f_gas > 0
                   FOR xml path ( '' )) AS VARCHAR)                                          preprice
      FROM t_sellinggas sg
               left join t_userinfo ui on ui.f_userinfo_id = sg.f_userinfo_id
               left join t_userfiles uf on uf.f_userfiles_id = sg.f_userfiles_id
               LEFT JOIN t_gasbrand gd ON uf.f_gasbrand_id = gd.id
               left join t_user_address ua on uf.f_useraddress_id = ua.id
               LEFT JOIN t_stairprice sp ON sp.id = sg.f_stairprice_id
               LEFT JOIN t_surplus_detail sd ON sg.id = sd.f_sell_id
      WHERE sg.f_state = '有效'
        and sg.f_surplus_id is null
        and sg.f_type in ('卡表收费', '发卡售气')
        and {condition}) ss
ORDER BY f_operate_date desc

==> sale-3.7.1.jar: filiale/xiangyun/sqls/cardChargeQuery.sql <==
SELECT *
     , LEFT(price
    , len(price) - 1)   f_price    --预收气价
     ,
    case when f_price_type = '应交费' then LEFT(price , len(price) - 1) else LEFT(preprice , (len(price) - 1)) end f_preprice --应收气价
FROM (SELECT sg.id                                                                           id,
             sg.f_preamount,                                                                               --预收气费
             sg.f_pregas,                                                                                  --购气量
            case when sg.f_price_type = '应交费' then sg.f_preamount else sg.f_preamount - sg.f_pregas * isnull(sp.f_add_price, 0)  end    f_realamount, --应收气费
             sg.f_operate_date,
             case when sd.id is null then '否' else '是' end                                 f_refund,
             case when sd.id is null then 0 else sg.f_pregas * isnull(sp.f_add_price, 0) end f_refundfee,
             ui.f_userinfo_code,
             ui.f_user_name,
             sg.f_orgid,
             sg.f_orgname,
             sg.f_depid,
             sg.f_depname,
             sg.f_operatorid,
             sg.f_operator,
    sg.f_price_type,
    case
    when sg.f_price_type = '应交费' then
    isnull(sg.f_stair_price1, 0)
    else
    (case
    when isnull(sg.f_stair_price1, 0) - isnull(sp.f_add_price, 0) < 0 then 0
    else isnull(sg.f_stair_price1, 0) - isnull(sp.f_add_price, 0) end) end f_stair_price1,
    isnull(f_stair_gas1, 0)                                                             f_stair_gas1,
    case
    when sg.f_price_type = '应交费' then
    isnull(f_stair_money1, 0)
    else
    round( (isnull(f_stair_price1, 0) - isnull(sp.f_add_price, 0)) * f_stair_gas1,2)  end                                                        f_stair_money1,
    case
    when sg.f_price_type = '应交费' then
    isnull(f_stair_price2, 0)
    else (case
    when isnull(f_stair_price2, isnull(sp.f_add_price, 0)) -
    isnull(sp.f_add_price, 0) < 0 then 0
    else isnull(f_stair_price2, isnull(sp.f_add_price, 0)) -
    isnull(sp.f_add_price, 0) end)
    end                                                                             f_stair_price2,
    isnull(f_stair_gas2, 0)                                                             f_stair_gas2,
    case
    when sg.f_price_type = '应交费' then
    isnull(f_stair_money2, 0)
    else
    round( (isnull(f_stair_price2, 0) - isnull(sp.f_add_price, 0)) * f_stair_gas2,2)  end                                                        f_stair_money2,
    case
    when sg.f_price_type = '应交费' then
    isnull(f_stair_price3, 0)
    else
    (case
    when isnull(f_stair_price3, isnull(sp.f_add_price, 0)) -
    isnull(sp.f_add_price, 0) < 0 then 0
    else isnull(f_stair_price3, isnull(sp.f_add_price, 0)) -
    isnull(sp.f_add_price, 0) end) end                                f_stair_price3,
    isnull(f_stair_gas3, 0)                                                             f_stair_gas3,
    case
    when sg.f_price_type = '应交费' then
    isnull(f_stair_money3, 0)
    else
    round( (isnull(f_stair_price3, 0) - isnull(sp.f_add_price, 0)) * f_stair_gas3,2)  end                                                        f_stair_money3,
             gd.f_meter_brand,
             uf.f_meternumber,
             sg.f_user_type,
             sg.f_gasproperties,
             ua.f_address,
             sd.f_operate_date                                                               f_refund_date,
             CAST((SELECT '' + CAST(CONVERT(DECIMAL(18, 3), f_price) AS VARCHAR) + '|'
                   FROM t_chargeprice cp
                   WHERE sg.id = cp.f_charge_id
                     and cp.f_gas > 0
                   FOR xml path ( '' )) AS VARCHAR)                                          price,
             CAST((SELECT '' + CAST(CONVERT(DECIMAL(18, 3), f_price - isnull(sp.f_add_price, 0)) AS VARCHAR) + '|'
                   FROM t_chargeprice cp
                   WHERE sg.id = cp.f_charge_id
                     and cp.f_gas > 0
                   FOR xml path ( '' )) AS VARCHAR)                                          preprice,
             sg.f_payment,
             se.f_operate_date f_last_selldate --上次缴费时间
      FROM t_sellinggas sg
               left join (select f_operate_date,id from t_sellinggas) se on sg.f_last_sellid = se.id
               left join t_userinfo ui on ui.f_userinfo_id = sg.f_userinfo_id
               left join t_userfiles uf on uf.f_userfiles_id = sg.f_userfiles_id
               LEFT JOIN t_gasbrand gd ON uf.f_gasbrand_id = gd.id
               left join t_user_address ua on uf.f_useraddress_id = ua.id
               LEFT JOIN t_stairprice sp ON sp.id = sg.f_stairprice_id
               LEFT JOIN t_surplus_detail sd ON sg.id = sd.f_sell_id
      WHERE sg.f_state = '有效'
        and sg.f_surplus_id is null
        and sg.f_type in ('卡表收费', '发卡售气','物联网收费')
        and {condition}) ss
ORDER BY f_operate_date desc
